/************************************************************************/
/* hash.h - Simple string and binary hash library header		*/
/************************************************************************/
/*
 *  (c)2003 Todd Shadburn
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/

#ifndef _HASH_H_
#define _HASH_H_

#define HASH_FREE	0x01 /* Free just the structures */
#define HASH_FREE_ALL	0x02 /* Free all the keys and values too */


/* string hash structs and functions */
typedef struct _SHash	SHash;
struct _SHash {
	char *key;
	char *value;
	SHash *next;
};
typedef int (*shash_foreach_callback)(char *key, char *value, void *data);

int shash_add (SHash **shash, char *key, char *value);
int shash_remove (SHash **shash, char *key);
int shash_get (SHash *shash, char *key, char **value);
int shash_foreach (SHash *shash, shash_foreach_callback callback,
			void *data);
int shash_free(SHash **shash, int freetype);


/* binary hash structs and functions */
typedef struct _BHash	BHash;
struct _BHash {
	char *key;
	int keylen;
	char *value;
	int valuelen;
	BHash *next;
};
typedef int (*bhash_foreach_callback)(char *key, int keylen,
					char *value, int valuelen,
					void *data);

int bhash_add (BHash **bhash, char *key, int keylen,
		char *value, int valuelen);
int bhash_remove (BHash **bhash, char *key, int keylen);
int bhash_get (BHash *bhash, char *key, int keylen,
		char **value, int *valuelen);
int bhash_foreach (BHash *bhash, bhash_foreach_callback callback,
			void *data);
int bhash_free(BHash **bhash, int freetype);


#endif

